@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2011  Tom Cato Amundsen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -44,19 +44,22 @@ class Teacher(abstract.MelodicIntervalTeacher):
         """
         score = elems.Score()
         staff = score.add_staff()
-        staff.set_property(elems.Rat(0, 1), 'hide-barline', True)
-        staff.set_property(elems.Rat(0, 1), 'hide-timesignature', True)
+        staff.set_property(solfege.mpd.Rat(0, 1), 'hide-barline', True)
+        staff.set_property(solfege.mpd.Rat(0, 1), 'hide-timesignature', True)
         score.voice11.append(elems.Note(self.m_tonika,
             solfege.mpd.Duration(4, 0)))
         last = self.m_tonika
+        tones = [last]
         for i in self.m_question:
             n = mpd.Interval()
             n.set_from_int(i)
             last = last + n
             if abs(last.m_accidental_i) > 1:
                 last.normalize_double_accidental()
+            tones.append(last)
             score.voice11.append(elems.Note(last,
                 solfege.mpd.Duration(4, 0)))
+        score.m_staffs[0].set_clef(solfege.mpd.select_clef(u" ".join([x.get_octave_notename() for x in tones])), solfege.mpd.Rat(0, 1))
         return score
     def guessed_correct(self):
         if self.get_int('number_of_intervals=1') == 1 \
@@ -91,7 +94,7 @@ class Gui(abstract.Gui):
         ################
         # practise_box #
         ################
-        self.g_score_displayer = mpd.musicdisplayer.MusicDisplayer()
+        self.g_score_displayer = mpd.MusicDisplayer()
         self.practise_box.pack_start(self.g_score_displayer)
         self.g_score_displayer.clear()
         b1 = gu.bHBox(self.practise_box, False)
